<?php

/* 
 * dbplquery.inc - the script performing the database playlist query and creating the HTML output for it
 *
 * Copyright (c) by Andreas S. Krebs (andreas.krebs@web.de)
 *
 * this script expects in the variable $query the WHERE clause of the SQL query to perform
 * and returns in $entries_found the number of entries found in the database.
 *
 */

require_once("config.inc");
require_once("utils.inc");
require_once("dbutils.inc");

function createPLSearch_TABLE($query, $notfound_msg, $isSearch)
{
  global $DBCONNECT, $TABLE_BORDER, $MAX_ENTRIES, $SHOW_COLUMN, $QUERY_STRING, $HAS_JS, $SCRIPT_NAME, $LINKROOT, $M3UROOT, $ENTRY_ATTR;
  global $conn, $plsortby, $plstart;

  $table1=new TABLEtag(array("CELLSPACING"=>"4", 
			     "CELLPADDING"=>"0",
			     "BORDER"=>"$TABLE_BORDER",
			     "WIDTH"=>"100%"));

  if(!$conn)	// recycle connection if already existing
    $conn=pg_pconnect($DBCONNECT);
  if(!$conn)
  {
    $table1->push_row(create_TD(array("CLASS"=>"Navigation", "WIDTH"=>"100%", "ALIGN"=>"CENTER"),
				html_b("Failed to open the database \"$DBCONNECT\"")));
  }
  else
  {
    // Execute query (we also get the oid, also we don't need it yet)
    if($plsortby == "")
      $plsortby="title ASC";

    $sortdir="ASC";
    $isortdir="DESC";
    if(stristr($plsortby, "ASC") === false)
    {
      $sortdir="DESC";
      $isortdir="ASC";
    }

    if($query!="")
      $result=pg_exec($conn, createPlaylistQuery($query, $plsortby));

    $entries_found=pg_numrows($result);

    if($plstart >= $entries_found)		// make sure the start range is valid
      $plstart=0;

    if($entries_found <= 0)
    {
      $table1->push_row(create_TD(array("CLASS"=>"Navigation", "WIDTH"=>"100%", "ALIGN"=>"CENTER"),
			html_b("$notfound_msg")));
    }
    else
    {
      $end=$plstart + $MAX_ENTRIES;
      if($end > $entries_found)
        $end=$entries_found;

      if($entries_found>1)
      {
        $newquery=$QUERY_STRING;
        if($HAS_JS)
        {
          $newquery=preg_replace("/&i_\d*=1/" , "", $newquery);		// remove all entries
        }

        $pageTxt=array();
        if($entries_found > $MAX_ENTRIES)
        {
          $pageHtml=getPageHTML($SCRIPT_NAME."?".$newquery, $plstart, $entries_found, $MAX_ENTRIES);
          $pageTxt=array_merge(array(html_br()), $pageHtml);
        }

        $table1->push_row(
          create_TD(array("CLASS"=>"Navigation", "ALIGN"=>"CENTER", "COLSPAN"=>"4"),
                    create_B(array_merge(array("Entries ". ($plstart+1) ." - $end of $entries_found"), $pageTxt))));

        $newquery=ereg_replace("plsortby=.*&", "", $newquery);
        $newquery=ereg_replace("&plsortby=.*$", "", $newquery);  // in case we are at the end of the query
        $newquery=$SCRIPT_NAME . "?" . $newquery . "&plsortby=";

        $isortby=ereg_replace($sortdir, $isortdir, $plsortby);
        $indirquery=$prefix . htmlspecialchars($newquery . $isortby) . $postfix;

        $sortimg=ereg_replace("ASC", "images/down.gif", $isortdir);
        $sortimg=ereg_replace("DESC", "images/up.gif", $sortimg);
 
        $sortalt=ereg_replace("ASC", "[Down]", $isortdir);
        $sortalt=ereg_replace("DESC", "[UP]", $isortdir);
        $newquery=$prefix . htmlspecialchars($newquery);

	$t1r1=new TRtag();
        $t1r1->push(
           create_TD(array("CLASS"=>"Column", "WIDTH"=>"1%", "ALIGN"=>"CENTER"),
		     html_img_href("$indirquery", "$sortimg", '', '', 0, "$sortalt")),
	   create_TD(array("CLASS"=>"Column", "WIDTH"=>"1%")));

        $t1r1->push(create_TD(array("CLASS"=>"Column", "WIDTH"=>"100%", "ALIGN"=>"CENTER"),
                    html_b(html_a("$newquery"."title+$sortdir", "Title"))));
      }
      else  // no need for sorting links, cause we have only one entry 
      {
        $t1r1=new TRtag();
        $t1r1->push(
           create_TD(array("CLASS"=>"Column", "WIDTH"=>"1%")),
           create_TD(array("CLASS"=>"Column", "WIDTH"=>"1%")));

        $t1r1->push(create_TD(array("CLASS"=>"Column", "WIDTH"=>"30%", "ALIGN"=>"CENTER"),
                    html_b("Title")));
      }

      $t1r1->push(create_TD(array("CLASS"=>"Column", "WIDTH"=>"1%"), html_b("Edit")));

      $table1->push($t1r1);

      // Get results from database
      $rows=$plstart;
      while($rows < $end)
      {
        $playlist=pg_fetch_object($result, $rows);

        // convert html special chars where needed
        $playlist->title=htmlspecialchars($playlist->title);

        if(strlen($playlist->file)>0)
        {
          $playlist->fileurl=rawurlencode($M3UROOT . $playlist->file);
        }

        // create a table row for this entry 
        $style="Entry";
        if(strlen($song->album)==0 && $song->track==false)
          $style="NoEntry";

        $t1r1=new TRtag();

        $t1r1->push(
          create_TD(array_merge(array("CLASS"=>"Number", "ALIGN"=>"RIGHT"), $ENTRY_ATTR),
	            html_a("plinfo.php?plid=$playlist->id", $rows+1, NULL, "_blank")),
          create_TD(array_merge(array("CLASS"=>"Button"), $ENTRY_ATTR),
	            html_img_href("irmp3cmd.php?comand=playpl&plid=$playlist->id&playlist=$playlist->fileurl", "images/play.gif", '', '', 0, "[Play]", NULL, "player")));

        $t1r1->push(create_TD(array_merge(array("CLASS"=>"Entry"), $ENTRY_ATTR),
		    html_a("search.php?plid=$playlist->id", $playlist->title, NULL, "muwed")));

        $t1r1->push(create_TD(array_merge(array("CLASS"=>"Button"), $ENTRY_ATTR),
		    html_img_href("manage/pledit.php?plid=$playlist->id", "images/edit.gif", '', '', 0, "[Edit]", "_blank")));
        $table1->push($t1r1);

        $rows++;
      }

      if($entries_found > $MAX_ENTRIES)
      {
        $table1->push_row(
	  create_TD(array("CLASS"=>"Navigation", "ALIGN"=>"MIDDLE", "COLSPAN"=>"4"),
		    create_B($pageHtml)));
      }
    }
  }

  return $table1;
}

function getPageHTML($query, $plstart, $num, $max)
{
  global $HAS_JS;

  $query=ereg_replace("plstart=.*&", "", $query);
  $query=ereg_replace("&plstart=.*^", "", $query);  // in case we are at the end of the query
  $query=$query . "&plstart=";

  $query=htmlspecialchars($query);
  $html=array();
  if($num > $max)
  {
    $prev=$plstart - $max;
    if($prev < 0)
      $prev=-1;

    $next=$plstart + $max;
    if($next >= $num)
      $next=-1;

    if($prev >= 0)
    {
      $html[]=html_a($query ."0", "&lt;&lt");
      $html[]=" ";
      $html[]=html_a($query . $prev, "&lt");
    }
    else
      $html[]="&lt;&lt; &lt;";

    $cnt=1;
    for($i=0; $i<$num; $i+=$max)
    {
      if($i != $plstart)
      {
        $html[]=html_a($query . $i, "$cnt");
	$html[]=" ";
      }
      else
      {
        $html[]=create_B("$cnt", array("style"=>"color: #99aabb"));
      }

      $end=$i;
      $cnt++;
    }

    if($next >= 0)
    {
      $html[]=html_a($query . $next, "&gt;");
      $html[]=" ";
      $html[]=html_a($query . $end, "&gt;&gt;");
    }
    else
      $html[]="&gt; &gt;&gt;";
  }

  return $html;
}

?>
